@@ -117,17 +117,10 @@ class objearth():
         return xarray.merge([blue,green,red,nir,pixel_qa])
 
     @staticmethod
-    def plotshow(DataArray,cmap=True,area=True,zenmode=False,figsize=(8,8),xlabel="x axis size",ylabel="y axis size",title=''):
+    def plotshow(DataArray,cmap=True,area=True,ts=0.07,zenmode=False,figsize=(8,8),xlabel="x axis size",ylabel="y axis size",title=''):
         '''
         Plot image 
         :param DataArray : Numpy array/Xarray data array
-        :param area      : area that you want [y-up,y-dwon,x-left,x-right]
-        :param figsize   : size of image
-        :param camp      : colormap
-        :param zonmode   : plotshow only image no any detail
-        :param xlabel    : x-axis label
-        :param ylabel    : y-axis label
-        :param title     : title label
         '''
         if type(DataArray) == xarray.core.dataarray.DataArray:
             if area==True:
@@ -158,7 +151,7 @@ class objearth():
             secax_x.set_xlabel('longitude')
             secax_y = ax.secondary_yaxis('right',functions=(latitude,axis))
             secax_y.set_ylabel('latitute')
-            plt.grid(color='w', linestyle='-', linewidth=0.15)
+            plt.grid(color='w', linestyle='-', linewidth=ts)
             plt.show()
         #Area
         elif type(DataArray) == numpy.ndarray:
@@ -172,12 +165,13 @@ class objearth():
 
             #plotshow
             plt.figure(figsize=(figsize))
+            plt.subplots(constrained_layout=True)
             color_map = plt.imshow(real_margin_img,extent=[xmin,xmax,ymin,ymax])
             if zenmode != True:
                 plt.title(title)
                 plt.xlabel(xlabel)
                 plt.ylabel(ylabel)
-                plt.grid(color='w', linestyle='-', linewidth=0.15)
+                plt.grid(color='w', linestyle='-', linewidth=ts)
             else:
                 plt.axis('off')
 
@@ -236,12 +230,6 @@ class objearth():
         ndvi1 = (nir-red)/(nir+red).to_numpy()
         ndvi3 = numpy.clip(ndvi1,-1,1)
         im_ratio = ndvi3.shape[1]/ndvi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(ndvi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
         return ndvi3
 
     def EVI(self,DataArray):
@@ -278,12 +266,6 @@ class objearth():
         ndmi1 = (nir-swir)/(nir+swir).to_numpy()
         ndmi3 = numpy.clip(ndmi1,-1,1)
         im_ratio = ndmi3.shape[1]/ndmi3.shape[0]
-        plt.figure(figsize=(8,8))
-        plt.xticks([]), plt.yticks([])
-        plt.imshow(ndmi3,cmap='viridis')
-        plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
-        plt.show()
         return ndmi3
 
     def BSI(self,DataArray):
@@ -663,8 +645,7 @@ import numpy as np
 from matplotlib import colorbar
 
 
-
-class water:
+class Water:
         #fix
         required_bands = {'mndi','Green','ndwi','Mir2','mbwi'}
         required_indices = {'ndwi','mbwi','mndwi'}
@@ -699,14 +680,33 @@ class water:
         classifier = 'naivebayes'
         clustering_method = 'agglomerative'
         
-        def __init__(self,input_bands):
-            self.input_bands = input_bands   
+        def __init__(self,dataset):
+            # new
+            if isinstance(dataset,xarray.core.dataset.Dataset):
+                try:
+                    red   = dataset.red.to_numpy()
+                    green = dataset.green.to_numpy()
+                    blue  = dataset.blue.to_numpy()
+                    nir   = dataset.nir.to_numpy()
+                    mir   = dataset.swir1.to_numpy()
+                    mir2  = dataset.swir2.to_numpy()
+                except ValueError as e:
+                    print(e)
+                bands = {'Red':red,
+                         'Green':green,
+                         'Blue':blue,
+                         'Nir':nir,
+                         'Mir':mir,
+                         'Mir2':mir2}
+                dataset = bands
+            # old
+            self.input_bands = dataset
             bands = dict()
             for i,j in self.input_bands.items():
                 quantize = j.squeeze()/10000
                 bands.update({i:quantize})
             self.bands=bands
-            
+
         def __str__(self):
             lst = list()
             for i in self.bands.keys():
@@ -1319,8 +1319,7 @@ class water:
             return tsm 
 
         ################################################ waterquality #################################################
-
-        def waterquality(self,watermask,waterquality_function=None,range=None,colormap=True,bright=5,title='',label=''):
+        def waterquality(self,watermask=None,waterquality_function=None,range=None,colormap=None,bright=5,title='',label=''):
             """
             waterquality (Main fn)
             :param watermask             : water mask area that want to burn
@@ -1332,15 +1331,19 @@ class water:
             :param label                 : label of colorbar
             :return                      : R,G,B array
             """
+            
             # Watermask
-            self.watermask = watermask
+            if(watermask==None):
+                self.watermask = self.waterdetect()
+            else:
+                self.watermask = watermask
 
             # Reference band , Prepare parameter
             if waterquality_function == None:
                 parameter = self.waterquality_fn(self.bands['Red'])
             else: 
                 parameter = waterquality_function(self.bands['Red'])  # fix : bands that the same with input function
-            parameter = self.apply_mask(parameter,~watermask,-9999)
+            parameter = self.apply_mask(parameter,~self.watermask,-9999)
             
             # Min Max range value
             if range == None:
@@ -1350,18 +1353,18 @@ class water:
                 self.max_value = range[1]
 
             # Color map 
-            if colormap != True:
+            if colormap != None:
                 cmap = plt.get_cmap(colormap)
             else:
                 cmap = objearth.bluesea()
 
-            # Color bar
-            fig = plt.figure(figsize=(4,1))
-            ax1 = fig.add_axes([0.05,0.50,1.65,0.35])
-            norm = colors.Normalize(vmin=self.min_value,vmax=self.max_value)
-            cb1 = colorbar.ColorbarBase(ax1,cmap=cmap,norm=norm,orientation='horizontal')
-            ax1.set_title(title)
-            cb1.set_label(label)
+            # # Color bar
+            # fig = plt.figure(figsize=(4,1))
+            # ax1 = fig.add_axes([0.05,0.50,1.65,0.35])
+            # norm = colors.Normalize(vmin=self.min_value,vmax=self.max_value)
+            # cb1 = colorbar.ColorbarBase(ax1,cmap=cmap,norm=norm,orientation='horizontal')
+            # ax1.set_title(title)
+            # cb1.set_label(label)
 
             # Prepare RGB bands
             self.bright = bright
@@ -1389,9 +1392,60 @@ class water:
 
             # plotshow Result
             rgb = np.stack([red,green,blue],axis=2)
-            objearth.plotshow(rgb)
+            # objearth.plotshow(rgb)
             # plt.figure(figsize=(8,8))
             # plt.axis('off')
             # plt.imshow(rgb)
             
-            return red*10000,green*10000,blue*10000
+            # return red*10000,green*10000,blue*10000
+            return rgb
+
+
+class imagedataset(objearth,Water):
+    def __init__(self,image_dataset):
+        self.ids = image_dataset
+    def detail(self):
+        print(self.ids)
+    def listtime(self):
+        output_list = []
+        rnd = self.ids.dims['time']
+        for i in range(rnd):
+            t = self.ids.isel(time=i).time.values
+            print(t)
+    def operator(self,command):
+        r = self.ids.dims['time']
+        output_dict = {}
+        for i in range(r):
+            t = self.ids.isel(time=i).time.values
+            eds = self.ids.isel(time=i)
+            if command == 'truecolor':
+                val = super().truecolor(eds)
+            elif command == 'NDVI':
+                val = super().NDVI(eds)
+            elif command == 'NDMI':
+                val = super().NDMI(eds)
+            elif command == 'waterdetect':
+                val = Water(eds).waterdetect()
+            elif command == 'waterquality':
+                val = Water(eds).waterquality()
+            else:
+                print('Errro command')
+                break
+            # print(rgb)
+            # 1 key
+            key = 'key'+str(i)
+            # 2.output_value (data)
+            data=val
+            # 3.output_data (label)
+            label=t
+            #output_dict
+            output_dict.update({key:[data,label]})
+        return output_dict
+    def show(self,od,**z):
+        r = self.ids.dims['time']
+        for i in range(r):
+            k = 'key'+str(i)
+            if z:
+                objearth.plotshow(od[k][0],figsize=(6,6),title=od[k][1],area=z['area'])
+            else:
+                objearth.plotshow(od[k][0],figsize=(6,6),title=od[k][1])
\ No newline at end of file
